@@ -14,7 +14,7 @@ test_that("expand_dates is functional", {
     id = c("1111", "2222", "3333"),
     gender = c("M", "F", "F"),
     start = c("2018-01-01", "2019-01-01", "2020-01-01"),
-    end = c("2018-01-05", "2019-01-07", "2020-01-08")
+    end = c("2018-01-05", "2019-01-07", "2020-01-08"), stringsAsFactors = TRUE
   )
 
   output_date <-
@@ -212,7 +212,7 @@ test_that("expand_times is functional", {
     id = c("1111", "2222", "3333"),
     gender = c("M", "F", "F"),
     start = c("2018-01-01 15:00:00", "2019-01-01 14:00:00", "2020-01-01 19:00:00"),
-    end = c("2018-01-01 18:30:00", "2019-01-01 17:30:00", "2020-01-02 02:00:00")
+    end = c("2018-01-01 18:30:00", "2019-01-01 17:30:00", "2020-01-02 02:00:00"), stringsAsFactors = TRUE
   )
 
   output_time <-
