@@ -11,7 +11,7 @@ test_that("partition_ranges is functional when partitioning by year", {
 
   df <- data.frame(group = c("a", "a", "b", "b", "c"),
                    start = c("2017-05-01", "2019-04-03", "2011-03-03", "2014-05-07", "2017-02-01"),
-                   end = c("2018-09-01", "2020-04-03", "2012-05-03", "2016-04-02", "2017-04-05")
+                   end = c("2018-09-01", "2020-04-03", "2012-05-03", "2016-04-02", "2017-04-05"), stringsAsFactors = TRUE
   )
 
   output <-
@@ -70,7 +70,7 @@ test_that("partition_ranges is functional when partitioning by month", {
 
   df <- data.frame(group = c("a", "a", "b", "b", "c", "d", "d"),
                    start = c("2017-05-01", "2019-04-03", "2011-03-03", "2014-05-07", "2017-02-01", "2018-01-01", "2019-01-01"),
-                   end = c("2018-09-01", "2020-04-03", "2012-05-03", "2016-04-02", "2017-04-05", "2018-01-30", "2019-03-05")
+                   end = c("2018-09-01", "2020-04-03", "2012-05-03", "2016-04-02", "2017-04-05", "2018-01-30", "2019-03-05"), stringsAsFactors = TRUE
   )
 
   output <- structure(list(group = structure(c(1L, 1L, 1L, 1L, 1L, 1L, 1L,
@@ -167,7 +167,7 @@ test_that("error when wrong partition by arg", {
   
   df <- data.frame(group = c("a", "a", "b", "b", "c", "d", "d"),
                    start = c("2017-05-01", "2019-04-03", "2011-03-03", "2014-05-07", "2017-02-01", "2018-01-01", "2019-01-01"),
-                   end = c("2018-09-01", "2020-04-03", "2012-05-03", "2016-04-02", "2017-04-05", "2018-01-30", "2019-03-05")
+                   end = c("2018-09-01", "2020-04-03", "2012-05-03", "2016-04-02", "2017-04-05", "2018-01-30", "2019-03-05"), stringsAsFactors = TRUE
   )
   
   output <- structure(list(group = structure(c(1L, 1L, 1L, 1L, 1L, 1L, 1L,
@@ -204,7 +204,7 @@ test_that("partition_ranges is functional when partitioning by month, w/o same m
   
   df <- data.frame(group = c("a", "a", "b", "b", "c", "d", "d"),
                    start = c("2017-05-01", "2019-04-03", "2011-03-03", "2014-05-07", "2017-02-01", "2018-01-01", "2019-01-01"),
-                   end = c("2018-09-01", "2020-04-03", "2012-05-03", "2016-04-02", "2017-04-05", "2018-03-30", "2019-03-05")
+                   end = c("2018-09-01", "2020-04-03", "2012-05-03", "2016-04-02", "2017-04-05", "2018-03-30", "2019-03-05"), stringsAsFactors = TRUE
   )
   
   output <- structure(list(group = structure(c(1L, 1L, 1L, 1L, 1L, 1L, 1L, 
